@@ -49,18 +49,6 @@
 #include "factor.h"
 
 #if IMPL_BORNEMANN
-static int is_primitive_root(UV n, UV r)
-{
-  UV fac[MPU_MAX_FACTORS+1];
-  int i, nfacs;
-  /* if ( (r&1) & powmod(n, (r-1)>>1, r) == 1 )  return 0; */
-  nfacs = factor_exp(r-1, fac, 0);
-  for (i = 0; i < nfacs; i++) {
-    UV m = powmod(n, (r-1)/fac[i], r);
-    if (m == 1) return 0;
-  }
-  return (gcd_ui(n,r) == 1);
-}
 /* We could use lgamma, but it isn't in MSVC and not in pre-C99.  The only
  * sure way to find if it is available is test compilation (ala autoconf).
  * Instead, we'll just use our own implementation.
@@ -184,7 +172,7 @@ static void poly_mod_sqr(UV* px, UV* res, UV r, UV mod)
       sum += (s_end*2 == d)  ?  c*c  :  2*c*px[d-s_end];
       rindex = (d < r) ? d : d-r;  /* d % r */
       res[rindex] = (res[rindex] + sum) % mod;
-#if defined(HAVE_UINT128)
+#if HAVE_UINT128
     } else {
       uint128_t max = ((uint128_t)1 << 127) - 1;
       uint128_t c128, sum128 = 0;
