@@ -118,15 +118,12 @@ sub prime_count_approx {
 }
 sub twin_prime_count {
   my($low,$high) = @_;
-  if (scalar @_ > 1) {
-    _validate_positive_integer($low);
-    _validate_positive_integer($high);
-  } else {
-    ($low,$high) = (2, $low);
-    _validate_positive_integer($high);
-  }
   return Math::Prime::Util::PP::twin_prime_count($low,$high);
 }
+sub ramanujan_prime_count {
+  my($low,$high) = @_;
+  return Math::Prime::Util::PP::ramanujan_prime_count($low,$high);
+}
 sub sum_primes {
   my($low,$high) = @_;
   return Math::Prime::Util::PP::sum_primes($low,$high);
@@ -524,6 +521,18 @@ sub valuation {
   _validate_positive_integer($k);
   return Math::Prime::Util::PP::valuation($n, $k);
 }
+sub todigits {
+  my($n,$base,$len) = @_;
+  return Math::Prime::Util::PP::todigits($n,$base,$len);
+}
+sub todigitstring {
+  my($n,$base,$len) = @_;
+  return Math::Prime::Util::PP::todigitstring($n,$base,$len);
+}
+sub fromdigits {
+  my($n,$base) = @_;
+  return Math::Prime::Util::PP::fromdigits($n,$base);
+}
 sub hammingweight {
   my($n) = @_;
   $n = -$n if defined $n && $n < 0;
@@ -637,6 +646,44 @@ sub vecreduce (&@) {    ## no critic qw(ProhibitSubroutinePrototypes)
   $a;
 }
 
+sub vecany (&@) {       ## no critic qw(ProhibitSubroutinePrototypes)
+  my $sub = shift;
+  { my $pp; local *_ = \$pp;
+    for my $v (@_) { $pp = $v; return 1 if $sub->(); }
+  }
+  undef;
+}
+sub vecall (&@) {       ## no critic qw(ProhibitSubroutinePrototypes)
+  my $sub = shift;
+  { my $pp; local *_ = \$pp;
+    for my $v (@_) { $pp = $v; return if !$sub->(); }
+  }
+  1;
+}
+sub vecnone (&@) {      ## no critic qw(ProhibitSubroutinePrototypes)
+  my $sub = shift;
+  { my $pp; local *_ = \$pp;
+    for my $v (@_) { $pp = $v; return if $sub->(); }
+  }
+  1;
+}
+sub vecnotall (&@) {    ## no critic qw(ProhibitSubroutinePrototypes)
+  my $sub = shift;
+  { my $pp; local *_ = \$pp;
+    for my $v (@_) { $pp = $v; return 1 if !$sub->(); }
+  }
+  undef;
+}
+
+sub vecfirst (&@) {     ## no critic qw(ProhibitSubroutinePrototypes)
+  my $sub = shift;
+  #for (@_) { return $_ if &{$sub}(); }  return undef;
+  { my $pp; local *_ = \$pp;
+    for my $v (@_) { $pp = $v; return $v if $sub->(); }
+  }
+  undef;
+}
+
 sub vecextract {
   my($aref, $mask) = @_;
   croak "vecextract first argument must be an array reference"
@@ -681,7 +728,7 @@ Dana Jacobsen E<lt>dana@acm.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2014-2015 by Dana Jacobsen E<lt>dana@acm.orgE<gt>
+Copyright 2014-2016 by Dana Jacobsen E<lt>dana@acm.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
