@@ -17,19 +17,24 @@ extern UV  nth_prime(UV x);
 extern UV  nth_prime_upper(UV x);
 extern UV  nth_prime_lower(UV x);
 extern UV  nth_prime_approx(UV x);
-extern UV  prime_count_lower(UV x);
 extern UV  prime_count_upper(UV x);
+extern UV  prime_count_lower(UV x);
 extern UV  prime_count_approx(UV x);
 extern UV  twin_prime_count(UV low, UV high);
 extern UV  twin_prime_count_approx(UV n);
 extern UV  nth_twin_prime(UV n);
 extern UV  nth_twin_prime_approx(UV n);
-extern UV  nth_ramanujan_prime(UV n);
 extern UV* n_ramanujan_primes(UV n);
 extern UV* n_range_ramanujan_primes(UV nlo, UV nhi);
+extern UV* ramanujan_primes(UV* first, UV* last, UV low, UV high);
 extern int is_ramanujan_prime(UV n);
-extern UV ramanujan_prime_count_lower(UV n);
-extern UV ramanujan_prime_count_upper(UV n);
+extern UV  ramanujan_prime_count(UV lo, UV hi);
+extern UV  ramanujan_prime_count_upper(UV n);
+extern UV  ramanujan_prime_count_lower(UV n);
+extern UV  ramanujan_prime_count_approx(UV n);
+extern UV  nth_ramanujan_prime(UV n);
+extern UV  nth_ramanujan_prime_upper(UV n);
+extern UV  nth_ramanujan_prime_lower(UV n);
 extern int sum_primes(UV low, UV high, UV *sum);
 extern void print_primes(UV low, UV high, int fd);
 
@@ -73,6 +78,7 @@ extern UV znorder(UV a, UV n);
 extern int is_primitive_root(UV a, UV p);
 #define is_square_free(n)  (moebius(n) != 0)
 extern int is_carmichael(UV n);
+extern int is_quasi_carmichael(UV n);
 
 extern IV stirling2(UV n, UV m);
 extern IV stirling1(UV n, UV m);
@@ -81,6 +87,10 @@ extern IV ramanujan_tau(UV n);
 
 extern int strnum_minmax(int min, char* a, STRLEN alen, char* b, STRLEN blen);
 
+extern int from_digit_string(UV* n, const char* s, int base);
+extern int to_digit_array(int* bits, UV n, int base, int length);
+extern int to_digit_string(char *s, UV n, int base, int length);
+
 extern int is_catalan_pseudoprime(UV n);
 
 extern UV gcdz(UV x, UV y);
